@@ -514,8 +514,12 @@ void MainWindow::runscript(QString command)
         sleep(2);
         system("killall hildon-status-menu");
         sleep(2);
+        system("ps ax | grep -v grep | grep osso-abook-home-applet > /dev/null && killall osso-abook-home-applet && sleep 2 &&  ps ax | grep -v grep | grep osso-abook-home-applet || /usr/sbin/dsmetool -t /usr/bin/osso-abook-home-applet");
+        sleep(2);
         system("killall systemui");
         sleep(2);
+        system("killall browser browserd");
+        sleep(2);
         system("killall rtcom-messaging-ui");
         progress.setValue(99);
         sleep(2);
@@ -755,9 +759,9 @@ void MainWindow::on_about_triggered()
 {
     QMessageBox msgBox;
     msgBox.setWindowTitle(tr("About Theme Customizer"));
-    msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
+    msgBox.setText("Author: D-Iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-37<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-38<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
