@@ -4,6 +4,7 @@
 #include <QDialog>
 #include <QFile>
 #include <QDir>
+#include <QListWidget>
 
 namespace Ui {
     class managepresets;
@@ -23,7 +24,7 @@ private:
     Ui::managepresets *ui;
 
 private slots:
-    void on_presetslist_currentIndexChanged(int index);
+    void on_presetslist_currentRowChanged(int currentRow);
     void readpresets();
 };
 
