@@ -13,6 +13,36 @@
         <source>Restore theme files</source>
         <translation>Tiedostojen palautus</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Delete saved themes</source>
+        <translation>Poista tallennettuja teemoja</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Selected theme is currently in use!</source>
+        <translation>Valittu teema on käytössä!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
+        <translation>Et voi poistaa teemaa joka on parhaillaan aktiivinen.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Delete theme?</source>
+        <translation>Poistetaanko teema?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Are you sure you want to delete this theme?</source>
+        <translation>Oletko varma että haluat poistaa teeman?</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Theme deleted.</source>
+        <translation>Teema poistettu.</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Save as new theme</source>
@@ -36,7 +66,7 @@
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Saving new theme...</source>
-        <translation>Tallenetaan uutta teemaa...</translation>
+        <translation type="unfinished">Tallennetaan uutta teemaa...</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
@@ -518,4 +548,22 @@
         <translation>Tallenna</translation>
     </message>
 </context>
+<context>
+    <name>managethemes</name>
+    <message>
+        <location filename="managethemes.ui" line="0"/>
+        <source>Select theme:</source>
+        <translation>Valitse teema:</translation>
+    </message>
+    <message>
+        <location filename="managethemes.ui" line="0"/>
+        <source>Delete</source>
+        <translation>Poista</translation>
+    </message>
+    <message>
+        <location filename="managethemes.cpp" line="0"/>
+        <source>No themes created by Theme Customizer found</source>
+        <translation>Ei löytynyt Theme Customizerin luomia teemoja</translation>
+    </message>
+</context>
 </TS>
